@@ -24,6 +24,12 @@ class ProfileUpdateContract(Contract):
     last_name = serializers.CharField(max_length=32)
     middle_name = serializers.CharField(max_length=32)
     birth_date = serializers.DateField()
+    state = serializers.CharField(max_length=32, allow_blank=True)
+    city = serializers.CharField(max_length=32, allow_blank=True)
+    street = serializers.CharField(max_length=32, allow_blank=True)
+    street_house = serializers.CharField(max_length=8, allow_blank=True)
+    street_apartment = serializers.CharField(max_length=8, allow_blank=True)
+    address = serializers.CharField(max_length=256, allow_blank=True)
 
 
 class ProfileCreateContract(ProfileUpdateContract):
@@ -82,6 +88,12 @@ class RussianProfileUpdateContract(ProfileUpdateContract):
 
 
 class RussianProfileUpdateAddressContract(Contract):
+    postal_code = serializers.CharField(max_length=16)
+    state = serializers.CharField(max_length=32)
+    city = serializers.CharField(max_length=32)
+    street = serializers.CharField(max_length=32)
+    street_house = serializers.CharField(max_length=8)
+    street_apartment = serializers.CharField(max_length=8, allow_blank=True)
     address = serializers.CharField(max_length=256)
 
 
